#
# spec file for package terminus
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           terminus
Version:        2.3.1
Release:        1.4
Summary:        An X terminal written in Vala
License:        GPL-3.0-only
Group:          System/X11/Terminals
URL:            https://www.rastersoft.com/programas/terminus.html
Source:         https://gitlab.com/rastersoft/terminus/-/archive/%{version}/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.30
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(keybinder-3.0)
BuildRequires:  pkgconfig(vte-2.91)
Recommends:     %{name}-lang
Suggests:       gnome-shell-extension-terminus

%description
A terminal with the capabilities of Guake and Terminator.

%package -n     gnome-shell-extension-terminus
Summary:        Show Terminus Quake Mode
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
Requires:       gnome-shell
BuildArch:      noarch

%description -n gnome-shell-extension-terminus
Allows to show the Quake-like terminal from Terminus by pressing the
defined hotkey.

%lang_package

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}
%fdupes %{buildroot}/%{_datadir}

rm %{buildroot}%{_datadir}/doc/terminus/CMakeLists.txt
rm %{buildroot}%{_datadir}/terminus/CMakeLists.txt

%files
%license LICENSE
%doc HISTORY.md README.md
%{_bindir}/terminus
%{_bindir}/terminus_showhide
%{_datadir}/applications/terminus.desktop
%{_datadir}/dbus-1/services/com.rastersoft.terminus.service
%{_datadir}/glib-2.0/schemas/org.rastersoft.terminus.gschema.xml
%{_datadir}/icons/hicolor/*/apps/terminus.??g
%{_datadir}/terminus/
%config %{_sysconfdir}/xdg/autostart/terminus_autorun.desktop

%files -n gnome-shell-extension-terminus
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/extensions
%{_datadir}/gnome-shell/extensions/showTerminusQuakeWindow@rastersoft.com/

%files lang -f %{name}.lang

%changelog
* Tue Apr 18 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.3.1:
  * Added support for gnome shell 44
  * Allow to reorder tabs
  * Added support for links
  * Removed debug prints
  * Added macros support
  * Show 30 characters in tabs
  * Fixed several leaks
* Mon Feb  6 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to version 2.1.0:
  * Ensure that the Guake window is always inside the screen
  * Fixed "new tab" operation after DnD into a new window
  * Added Drag'n'Drop support to move tiles between windows and tabs, or into a new window
  * Added "Select all" option
  * Added pointer autohide option
  * Added reset and clear options
  * Fixed Guake window zero height on first run
  * Fixed Guake keybinding failing until re-set
  * Added hotkeys to close a tile and a tab
  * Now asks for confirmation when trying to close a terminal with a running program
  * Fixed color scheme selection
  * Allows to change the top bar colors
  * Cleaned the color management code
  * Added support for Gnome Shell 43
  * Added shortcuts for horizontal and vertical split
  * Now the window doesn't get stuck in maximized mode when resized too much
  * Close the tabs with the central button
  * If there are too much tabs, show scroll buttons
  * Now the extension doesn't loose the connection with Terminus when the computer locks
  * Set a right value for the TERM environment variable
  * Use the user-defined terminal instead of /bin/bash by default
  * Migrated to GtkApplication
  * Don't relaunch terminus if the extension is disabled
  * Added zoom capabilities
  * Added key for showing the menu
* Thu Jul  1 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.13.0
  * Fixed guake mode gets the focus under X11 in gnome shell
  * If there is already a terminus instance when the extension is
    launched, it only shows the notification once
  * Fixed several warnings
* Wed May 13 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.12.0:
  * Fix popup menu translations
* Thu Apr 16 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.10.0:
  * Now it receives the focus under X11
* Mon Apr 13 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.9.0:
  * Now guarantees under Wayland that occupies the whole width
  * Changed license to GPLv3 only
* Sat Jan 11 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.8.0:
  * Now, under wayland, opens guake window in the mouse monitor
  * Fixed red color spilling outside the window
* Tue Oct 15 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.7.1:
  * Fixed red color spilling outside the window
* Sat Oct 12 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.7.0:
  * Fixed the right-click menu under Wayland
  * Fixed several compiling warnings
  * Removed deprecated calls
  * Now the Wayland version (under gnome shell) works like the
    X11 one (is shown over all windows, and in all workspaces)
  * Now the "guake" terminal is show always in the primary monitor
* Wed May  8 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.5.0:
  * Now PASTE works with clipboard managers
* Thu Mar 28 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.1:
  * Fixed COPY keybinding
  * Added keybindings for COPY and PASTE
  * Added keybindings to move focus between terminals in the same tab
* Fri Feb  8 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.3.0:
  * Allows to use the -e and -x parameters to create a new window
    an launch a command inside
  * Fixed the .desktop file to fully follow the standard
  * Added an screenshot in the README.md file
* Sun Oct 21 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.2.0:
  * Fixes Guake hotkey don't working on X11 with another terminus
    open
  * Added missing parameter in the help
* Thu Sep 20 2018 Alexei Podvalsky <avvissu@yandex.by>
- Initial package
